import { ApiProperty } from '@nestjs/swagger';
import { Column, Entity, JoinTable, ManyToMany, Relation } from 'typeorm';
import { CommonEntity } from '~/common/entity/common.entity';
import { MaterialsInOrOutEnum } from '~/constants/enum';
import { Storage } from '~/modules/tools/storage/storage.entity';

@Entity({ name: 'materials_in_out' })
export class MaterialsInOutEntity extends CommonEntity {
  @Column({
    name: 'product',
    type: 'int',
    comment: '产品名称'
  })
  @ApiProperty({ description: '产品名称' })
  product: number;
  
  @Column({
    name: 'unit',
    type: 'int',
    comment: '单位(字典)'
  })
  @ApiProperty({ description: '单位(字典)' })
  unit: number;

  @Column({
    name: 'inOrOut',
    type: 'tinyint',
    comment: '入库或出库'
  })
  @ApiProperty({ description: '入库或出库 0:入库 1:出库' })
  inOrOut: MaterialsInOrOutEnum;

  @Column({
    name: 'inventory_time',
    type: 'date',
    nullable: true,
    comment: '时间'
  })
  @ApiProperty({ description: '时间' })
  time: Date;

  @Column({
    name: 'quantity',
    type: 'int',
    default: 0,
    comment: '数量'
  })
  @ApiProperty({ description: '数量' })
  quantity: number;

  @Column({
    name: 'unit_price',
    type: 'decimal',
    precision: 10,
    default: 0,
    scale: 2,
    comment: '单价'
  })
  @ApiProperty({ description: '入库单价' })
  unitPrice: number;

  @Column({
    name: 'amount',
    type: 'decimal',
    precision: 10,
    default: 0,
    scale: 2,
    comment: '金额'
  })
  @ApiProperty({ description: '金额' })
  amount: number;

  @Column({ name: 'agent', type: 'varchar', length: 50, comment: '经办人', nullable: true })
  @ApiProperty({ description: '经办人' })
  agent: string;

  @Column({
    name: 'issuance_number',
    type: 'varchar',
    length: 100,
    comment: '领料单号'
  })
  @ApiProperty({ description: '领料单号' })
  issuanceNumber: string;

  @Column({ name: 'remark', type: 'varchar', length: 255, comment: '备注', nullable: true })
  @ApiProperty({ description: '备注' })
  remark: string;

  @Column({ name: 'project', type: 'varchar', length: 255, comment: '项目', nullable: false })
  @ApiProperty({ description: '项目' })
  project: string;

  @Column({ name: 'is_delete', type: 'tinyint', default: 0, comment: '是否删除' })
  @ApiProperty({ description: '删除状态：0未删除，1已删除' })
  isDelete: number;

  @ManyToMany(() => Storage, storage => storage.materialsInOut)
  @JoinTable({
    name: 'materials_in_out_storage',
    joinColumn: { name: 'materials_in_out_id', referencedColumnName: 'id' },
    inverseJoinColumn: { name: 'file_id', referencedColumnName: 'id' }
  })
  files: Relation<Storage[]>;
}
